@@ -12,8 +12,8 @@
 from twisted.python import log
 from os.path import isfile
 
-from amon.dansguardian import dans_tools
-from amon.dansguardian.config import dans_status
+from amon.guardian import dans_tools
+from amon.guardian.config import dans_status
 
 from ead2.backend.actions.amon import amon_tools as t
 from ead2.backend.actions import tools
@@ -327,7 +327,7 @@ def valid_opt_filters_form(form_result, zone):
     if dans_tools.reload():
         message += "\\nLe filtre a bien été rechargé."
     else:
-        log.err("Erreur au lancement de /etc/init.d/dansguardian reload(2) dans forms.py")
+        log.err("Erreur au lancement de /etc/init.d/eole-guardian reload(2) dans forms.py")
     return dict(message=message)
 
 def valid_filtrage_form(form_result, zone):
@@ -359,7 +359,7 @@ le {0} est désactivé.".format(zone_msg[zone])
     if dans_tools.reload():
         message += "\\nLe filtre a bien été rechargé."
     else:
-        log.err("Erreur au lancement de /etc/init.d/dansguardian reload(2) dans forms.py")
+        log.err("Erreur au lancement de /etc/init.d/eole-guardian reload(2) dans forms.py")
     return dict(message=message)
 
 def valid_sitelist_form(form_result, zone, keyword):
@@ -413,7 +413,7 @@ pour la politique %s." % (list_msg[antikeyword], policy))
     listed[site] = policies_checked
     dans_tools.save_site_list(listed, keyword, zone_indices[zone])
     if not dans_tools.reload():
-        log.err("Erreur au lancement de /etc/init.d/dansguardian \
+        log.err("Erreur au lancement de /etc/init.d/eole-guardian \
 reload(2) dans forms.py")
     return dict()
 
@@ -460,7 +460,7 @@ def valid_mod_list(data_names, data_table, zone, keyword):
 
     dans_tools.save_site_list(data_list, keyword, zone_indices[zone])
     if not dans_tools.reload():
-        log.err("Erreur au lancement de /etc/init.d/dansguardian \
+        log.err("Erreur au lancement de /etc/init.d/eole-guardian \
 reload(2) dans forms.py")
     return dict()
 
@@ -493,7 +493,7 @@ def valid_extension_form(form_result, zone):
                               'extension',
                               zone_indices[zone])
     if not dans_tools.reload():
-        log.err("Erreur au lancement de /etc/init.d/dansguardian \
+        log.err("Erreur au lancement de /etc/init.d/eole-guardian \
 reload(2) dans forms.py")
     return dict()
 
@@ -526,6 +526,6 @@ def valid_mime_form(form_result, zone):
                               'mime',
                               zone_indices[zone])
     if not dans_tools.reload():
-        log.err("Erreur au lancement de /etc/init.d/dansguardian \
+        log.err("Erreur au lancement de /etc/init.d/eole-guardian \
 reload(2) dans forms.py")
     return dict()
