@@ -34,7 +34,7 @@ zone_libelle = t.get_zone_libelle(2)
 signalement_msg = navigation_filters['signalement_msg']
 
 class FiltresWebPedago(Action):
-    """ gestion des filtres optionnels de dansguardian pour la zone pedago"""
+    """ gestion des filtres optionnels de guardian pour la zone pedago"""
     user_description = Dict(default={},
                             doc="description de l'éxécutant",
                             keys=['ip', 'name', 'role'])
@@ -502,7 +502,7 @@ class Signalement(Action):
 
 class NavigationWhiteSiteListpedago(Action):
     """ interface de gestion des utilisateurs(ips) en liste blanche
-        sur l'instance 0 de dansguardian
+        sur l'instance 0 de guardian
     """
     user_description = Dict(default={}, doc="description de l'éxécutant", keys=['ip', 'name', 'role'])
     name = 'navigation_whitesitelist_pedago'
